// import presetAttributify from '@unocss/preset-attributify'
import {
  defineConfig,
  presetAttributify,
  presetIcons,
  presetWind,
  presetTagify,
  presetTypography,
  transformerDirectives,
  transformerVariantGroup,
} from "unocss";
import { presetForms } from '@julr/unocss-preset-forms';
import { presetHeroPatterns } from '@julr/unocss-preset-heropatterns';
import { presetExtra } from 'unocss-preset-extra';

export default defineConfig({
  safelist: [
  ...["p-", "m-"].map((v)=> Array.from({ length: 8 }, (_, i: number) => `${v}${i + 1}`))
  ],
  content: {
    filesystem: [
      "**/*.{html,css,scss,rs}",
      "src/**/*.rs",
      "*/src/**/*.rs",
      "*/style/*.scss",
    ],
  },
  cli: {
    entry: {
      patterns: [
        "**/*.{html,css,scss,rs}",
        "src/**/*.rs",
        "*/src/**/*.rs",
        "*/style/*.scss",
      ],
      outFile: "./style/uno.css",
    },
  },
  presets: [
    presetWind(),
    presetAttributify({}),
    presetTagify({}),
    presetIcons({}),
    presetHeroPatterns(),
    presetTypography({}),
    presetForms(),
    presetExtra(),
  ],
  transformers: [transformerDirectives(), transformerVariantGroup()],
});
